@@ -407,7 +407,7 @@ class BaseAuthProtocol(object):
         :returns: The token data
         :rtype: dict
         """
-        raise NotImplemented()
+        raise NotImplementedError()
 
     def process_response(self, response):
         """Do whatever you'd like to the response.
@@ -570,7 +570,8 @@ class AuthProtocol(BaseAuthProtocol):
                 self.log.info(_LI('Deferring reject downstream'))
             else:
                 self.log.info(_LI('Rejecting request'))
-                message = 'The request you have made requires authentication.'
+                message = _('The request you have made requires '
+                            'authentication.')
                 body = {'error': {
                     'code': 401,
                     'title': 'Unauthorized',
@@ -579,7 +580,6 @@ class AuthProtocol(BaseAuthProtocol):
                 raise webob.exc.HTTPUnauthorized(
                     body=jsonutils.dumps(body),
                     headers=self._reject_auth_headers,
-                    charset='UTF-8',
                     content_type='application/json')
 
         if request.user_token_valid:
